import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class RemoveAppCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.RemoveApp")

    def execute(self, appId):
        if appId is None:
            raise Exception("appId is required")

        requestObj = [appId]

        result = self.executeCommand(requestObj, "Could not execute command")

        return SimpleResult(result, "RemoveApp was successful", "RemoveApp failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class Android_SendKeyCodeCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.Android_SendKeyCode")

    def execute(self, keyCode):
        if keyCode is None:
            raise Exception("keyCode is required")

        requestObj = [keyCode]

        result = self.executeCommand(requestObj, "Could not execute command")

        return SimpleResult(result, "Android_SendKeyCode was successful", "Android_SendKeyCode failed")



import sys

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult

import json
class InitDriverCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Mobile.InitDriver")
    
    def execute(self, appPath):
        if appPath is None:
            requestObj = []
        else:
            requestObj = [appPath]

        result = self.executeCommand(requestObj, "Could not execute command")
        
        return SimpleResult(result, "InitDriver was successful", "InitDriver failed")   